@@ -14,10 +14,11 @@ namespace logs
 class EventLogger;
 class Logger;
 
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
 /**
  * Creates new EventLogger instances.
  */
-class EventLoggerProvider
+class OPENTELEMETRY_DEPRECATED EventLoggerProvider
 {
 public:
   virtual ~EventLoggerProvider() = default;
@@ -31,5 +32,6 @@ public:
       nostd::shared_ptr<Logger> delegate_logger,
       nostd::string_view event_domain) noexcept = 0;
 };
+#endif
 }  // namespace logs
 OPENTELEMETRY_END_NAMESPACE
