@@ -2,9 +2,9 @@
 // SPDX-License-Identifier: Apache-2.0
 
 #pragma once
-#ifndef ENABLE_METRICS_PREVIEW
 
-#  include "opentelemetry/metrics/observer_result.h"
+#include "opentelemetry/metrics/observer_result.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace metrics
@@ -15,6 +15,9 @@ using ObservableCallbackPtr = void (*)(ObserverResult, void *);
 class ObservableInstrument
 {
 public:
+  ObservableInstrument()          = default;
+  virtual ~ObservableInstrument() = default;
+
   /**
    * Sets up a function that will be called whenever a metric collection is initiated.
    */
@@ -28,4 +31,3 @@ public:
 
 }  // namespace metrics
 OPENTELEMETRY_END_NAMESPACE
-#endif
