@@ -5,8 +5,8 @@
 
 #include <mutex>
 
-#include "opentelemetry/common/macros.h"
 #include "opentelemetry/common/spin_lock_mutex.h"
+#include "opentelemetry/metrics/meter_provider.h"
 #include "opentelemetry/metrics/noop.h"
 #include "opentelemetry/nostd/shared_ptr.h"
 #include "opentelemetry/version.h"
@@ -15,8 +15,6 @@ OPENTELEMETRY_BEGIN_NAMESPACE
 namespace metrics
 {
 
-class MeterProvider;
-
 /**
  * Stores the singleton global MeterProvider.
  */
