@@ -14,13 +14,12 @@
 
 #if !defined(OPENTELEMETRY_HAVE_STD_VARIANT)
 
-#  ifndef HAVE_ABSEIL
 // We use a LOCAL snapshot of Abseil that is known to compile with Visual Studio 2015.
 // Header-only. Without compiling the actual Abseil binary. As Abseil moves on to new
 // toolchains, it may drop support for Visual Studio 2015 in future versions.
 
-#    if defined(__EXCEPTIONS)
-#      include <exception>
+#  if defined(__EXCEPTIONS)
+#    include <exception>
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace nostd
 {
@@ -37,10 +36,9 @@ public:
 }
 }  // namespace nostd
 OPENTELEMETRY_END_NAMESPACE
-#      define THROW_BAD_VARIANT_ACCESS opentelemetry::nostd::throw_bad_variant_access()
-#    else
-#      define THROW_BAD_VARIANT_ACCESS std::terminate()
-#    endif
+#    define THROW_BAD_VARIANT_ACCESS opentelemetry::nostd::throw_bad_variant_access()
+#  else
+#    define THROW_BAD_VARIANT_ACCESS std::terminate()
 #  endif
 
 #  ifdef _MSC_VER
@@ -51,10 +49,7 @@ OPENTELEMETRY_END_NAMESPACE
 #    pragma warning(disable : 4127)  // conditional expression is constant
 #  endif
 
-#  ifdef HAVE_ABSEIL
-#    include "absl/types/variant.h"
-#  else
-#    include "opentelemetry/nostd/internal/absl/base/options.h"
+#  include "opentelemetry/nostd/internal/absl/base/options.h"
 
 namespace absl
 {
@@ -67,8 +62,7 @@ class variant;
 }  // namespace OTABSL_OPTION_NAMESPACE_NAME
 }  // namespace absl
 
-#    include "opentelemetry/nostd/internal/absl/types/variant.h"
-#  endif
+#  include "opentelemetry/nostd/internal/absl/types/variant.h"
 
 #  ifdef _MSC_VER
 #    pragma warning(pop)
@@ -77,17 +71,6 @@ class variant;
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace nostd
 {
-#  ifdef HAVE_ABSEIL
-using absl::bad_variant_access;
-using absl::get;
-using absl::get_if;
-using absl::holds_alternative;
-using absl::monostate;
-using absl::variant;
-using absl::variant_alternative_t;
-using absl::variant_size;
-using absl::visit;
-#  else
 using absl::OTABSL_OPTION_NAMESPACE_NAME::get;
 using absl::OTABSL_OPTION_NAMESPACE_NAME::get_if;
 using absl::OTABSL_OPTION_NAMESPACE_NAME::holds_alternative;
@@ -96,7 +79,6 @@ using absl::OTABSL_OPTION_NAMESPACE_NAME::variant;
 using absl::OTABSL_OPTION_NAMESPACE_NAME::variant_alternative_t;
 using absl::OTABSL_OPTION_NAMESPACE_NAME::variant_size;
 using absl::OTABSL_OPTION_NAMESPACE_NAME::visit;
-#  endif
 }  // namespace nostd
 OPENTELEMETRY_END_NAMESPACE
 
