@@ -14,6 +14,11 @@ public:
   explicit DestroyCounter(int *count) : count_{count} {}
   ~DestroyCounter() { ++*count_; }
 
+  DestroyCounter(const DestroyCounter &)            = default;
+  DestroyCounter &operator=(const DestroyCounter &) = default;
+  DestroyCounter(DestroyCounter &&)                 = default;
+  DestroyCounter &operator=(DestroyCounter &&)      = default;
+
 private:
   int *count_;
 };
