@@ -12,19 +12,19 @@
 #include "opentelemetry/exporters/otlp/otlp_file_log_record_exporter_factory.h"
 #include "opentelemetry/exporters/otlp/otlp_file_log_record_exporter_options.h"
 #include "opentelemetry/logs/logger_provider.h"
-#include "opentelemetry/logs/provider.h"
 #include "opentelemetry/nostd/shared_ptr.h"
 #include "opentelemetry/sdk/logs/exporter.h"
 #include "opentelemetry/sdk/logs/logger_provider.h"
 #include "opentelemetry/sdk/logs/logger_provider_factory.h"
 #include "opentelemetry/sdk/logs/processor.h"
+#include "opentelemetry/sdk/logs/provider.h"
 #include "opentelemetry/sdk/logs/simple_log_record_processor_factory.h"
 #include "opentelemetry/sdk/trace/exporter.h"
 #include "opentelemetry/sdk/trace/processor.h"
+#include "opentelemetry/sdk/trace/provider.h"
 #include "opentelemetry/sdk/trace/simple_processor_factory.h"
 #include "opentelemetry/sdk/trace/tracer_provider.h"
 #include "opentelemetry/sdk/trace/tracer_provider_factory.h"
-#include "opentelemetry/trace/provider.h"
 #include "opentelemetry/trace/tracer_provider.h"
 
 #ifdef BAZEL_BUILD
@@ -57,7 +57,7 @@ void InitTracer()
 
   // Set the global trace provider
   std::shared_ptr<opentelemetry::trace::TracerProvider> api_provider = tracer_provider;
-  trace::Provider::SetTracerProvider(api_provider);
+  trace_sdk::Provider::SetTracerProvider(api_provider);
 }
 
 void CleanupTracer()
@@ -70,7 +70,7 @@ void CleanupTracer()
 
   tracer_provider.reset();
   std::shared_ptr<opentelemetry::trace::TracerProvider> none;
-  trace::Provider::SetTracerProvider(none);
+  trace_sdk::Provider::SetTracerProvider(none);
 }
 
 void InitLogger()
@@ -81,7 +81,7 @@ void InitLogger()
   logger_provider = logs_sdk::LoggerProviderFactory::Create(std::move(processor));
 
   std::shared_ptr<opentelemetry::logs::LoggerProvider> api_provider = logger_provider;
-  opentelemetry::logs::Provider::SetLoggerProvider(api_provider);
+  logs_sdk::Provider::SetLoggerProvider(api_provider);
 }
 
 void CleanupLogger()
@@ -94,7 +94,7 @@ void CleanupLogger()
 
   logger_provider.reset();
   nostd::shared_ptr<logs::LoggerProvider> none;
-  opentelemetry::logs::Provider::SetLoggerProvider(none);
+  logs_sdk::Provider::SetLoggerProvider(none);
 }
 }  // namespace
 
