@@ -35,6 +35,11 @@ public:
 
   ~Span() override { std::cout << "~Span\n"; }
 
+  Span(const Span &)            = delete;
+  Span &operator=(const Span &) = delete;
+  Span(Span &&)                 = delete;
+  Span &operator=(Span &&)      = delete;
+
   // opentelemetry::trace::Span
   void SetAttribute(nostd::string_view /*name*/,
                     const common::AttributeValue & /*value*/) noexcept override
@@ -81,7 +86,12 @@ private:
 };
 }  // namespace
 
-Tracer::Tracer(nostd::string_view /*output*/) {}
+Tracer::Tracer(nostd::string_view /*output*/)
+{
+#if OPENTELEMETRY_ABI_VERSION_NO >= 2
+  UpdateEnabled(true);
+#endif
+}
 
 nostd::shared_ptr<trace::Span> Tracer::StartSpan(nostd::string_view name,
                                                  const common::KeyValueIterable &attributes,
