@@ -1,11 +1,13 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
-#include "opentelemetry/exporters/memory/in_memory_span_data.h"
-#include "opentelemetry/nostd/span.h"
-#include "opentelemetry/sdk/trace/span_data.h"
-
 #include <gtest/gtest.h>
+#include <memory>
+#include <utility>
+#include <vector>
+
+#include "opentelemetry/exporters/memory/in_memory_span_data.h"
+#include "opentelemetry/sdk/trace/span_data.h"
 
 using opentelemetry::exporter::memory::InMemorySpanData;
 using opentelemetry::sdk::trace::SpanData;
