@@ -5,7 +5,7 @@
 
 #include <memory>
 
-#include "opentelemetry/exporters/otlp/otlp_grpc_client.h"
+// IWYU pragma: no_include "opentelemetry/exporters/otlp/otlp_grpc_client.h"
 #include "opentelemetry/exporters/otlp/otlp_grpc_client_options.h"
 #include "opentelemetry/version.h"
 
@@ -15,6 +15,9 @@ namespace exporter
 namespace otlp
 {
 
+class OtlpGrpcClient;                // IWYU pragma: keep
+class OtlpGrpcClientReferenceGuard;  // IWYU pragma: keep
+
 /**
  * Factory class for OtlpGrpcClient.
  */
