@@ -6,6 +6,7 @@
 #include <memory>
 
 #include "opentelemetry/exporters/otlp/otlp_grpc_metric_exporter_options.h"
+#include "opentelemetry/nostd/shared_ptr.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
@@ -14,6 +15,8 @@ namespace exporter
 namespace otlp
 {
 
+class OtlpGrpcClient;
+
 /**
  * Factory class for OtlpGrpcMetricExporter.
  */
@@ -26,10 +29,17 @@ public:
   static std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> Create();
 
   /**
-   * Create a OtlpGrpcMetricExporter.
+   * Create a OtlpGrpcMetricExporter using the given options.
    */
   static std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> Create(
       const OtlpGrpcMetricExporterOptions &options);
+
+  /**
+   * Create a OtlpGrpcMetricExporter using the given options and gRPC client.
+   */
+  static std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> Create(
+      const OtlpGrpcMetricExporterOptions &options,
+      const std::shared_ptr<OtlpGrpcClient> &client);
 };
 
 }  // namespace otlp
