@@ -6,6 +6,7 @@
 #include <memory>
 
 #include "opentelemetry/exporters/otlp/otlp_http_metric_exporter_options.h"
+#include "opentelemetry/exporters/otlp/otlp_http_metric_exporter_runtime_options.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
 #include "opentelemetry/version.h"
 
@@ -31,6 +32,13 @@ public:
    */
   static std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> Create(
       const OtlpHttpMetricExporterOptions &options);
+
+  /**
+   * Create a OtlpHttpMetricExporter.
+   */
+  static std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> Create(
+      const OtlpHttpMetricExporterOptions &options,
+      const OtlpHttpMetricExporterRuntimeOptions &runtime_options);
 };
 
 }  // namespace otlp
