@@ -55,6 +55,10 @@ public:
   static void ConvertHistogramMetric(const opentelemetry::sdk::metrics::MetricData &metric_data,
                                      proto::metrics::v1::Histogram *const histogram) noexcept;
 
+  static void ConvertExponentialHistogramMetric(
+      const opentelemetry::sdk::metrics::MetricData &metric_data,
+      proto::metrics::v1::ExponentialHistogram *const histogram) noexcept;
+
   static void ConvertGaugeMetric(const opentelemetry::sdk::metrics::MetricData &metric_data,
                                  proto::metrics::v1::Gauge *const gauge) noexcept;
 
