@@ -2,9 +2,10 @@
 // SPDX-License-Identifier: Apache-2.0
 
 #include "opentelemetry/exporters/otlp/otlp_file_exporter_factory.h"
-
 #include "opentelemetry/exporters/otlp/otlp_file_exporter.h"
 #include "opentelemetry/exporters/otlp/otlp_file_exporter_options.h"
+#include "opentelemetry/exporters/otlp/otlp_file_exporter_runtime_options.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace exporter
@@ -21,7 +22,16 @@ std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> OtlpFileExporterFactory
 std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> OtlpFileExporterFactory::Create(
     const OtlpFileExporterOptions &options)
 {
-  std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> exporter(new OtlpFileExporter(options));
+  OtlpFileExporterRuntimeOptions runtime_options;
+  return Create(options, runtime_options);
+}
+
+std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> OtlpFileExporterFactory::Create(
+    const OtlpFileExporterOptions &options,
+    const OtlpFileExporterRuntimeOptions &runtime_options)
+{
+  std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> exporter(
+      new OtlpFileExporter(options, runtime_options));
   return exporter;
 }
 
