@@ -6,7 +6,12 @@
 // https://github.com/open-telemetry/opentelemetry-cpp/issues/880
 #include "opentelemetry/exporters/otlp/otlp_grpc_exporter.h"
 
+#include <memory>
+
 #include "opentelemetry/exporters/otlp/otlp_grpc_exporter_factory.h"
+#include "opentelemetry/exporters/otlp/otlp_grpc_exporter_options.h"
+#include "opentelemetry/sdk/trace/exporter.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace exporter
