@@ -45,6 +45,16 @@ OtlpGrpcExporterOptions::OtlpGrpcExporterOptions()
   retry_policy_backoff_multiplier = GetOtlpDefaultTracesRetryBackoffMultiplier();
 }
 
+OtlpGrpcExporterOptions::OtlpGrpcExporterOptions(void *)
+{
+  use_ssl_credentials = true;
+  max_threads         = 0;
+
+#ifdef ENABLE_ASYNC_EXPORT
+  max_concurrent_requests = 64;
+#endif
+}
+
 OtlpGrpcExporterOptions::~OtlpGrpcExporterOptions() {}
 
 }  // namespace otlp
