@@ -4,6 +4,7 @@
 #include "opentelemetry/exporters/otlp/otlp_http_log_record_exporter_options.h"
 #include "opentelemetry/exporters/otlp/otlp_environment.h"
 #include "opentelemetry/exporters/otlp/otlp_http.h"
+#include "opentelemetry/nostd/string_view.h"
 #include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
@@ -20,6 +21,10 @@ OtlpHttpLogRecordExporterOptions::OtlpHttpLogRecordExporterOptions()
       console_debug(false),
       timeout(GetOtlpDefaultLogsTimeout()),
       http_headers(GetOtlpDefaultLogsHeaders()),
+#ifdef ENABLE_ASYNC_EXPORT
+      max_concurrent_requests{64},
+      max_requests_per_connection{8},
+#endif
       ssl_insecure_skip_verify(false),
       ssl_ca_cert_path(GetOtlpDefaultLogsSslCertificatePath()),
       ssl_ca_cert_string(GetOtlpDefaultLogsSslCertificateString()),
@@ -36,12 +41,20 @@ OtlpHttpLogRecordExporterOptions::OtlpHttpLogRecordExporterOptions()
       retry_policy_initial_backoff(GetOtlpDefaultLogsRetryInitialBackoff()),
       retry_policy_max_backoff(GetOtlpDefaultLogsRetryMaxBackoff()),
       retry_policy_backoff_multiplier(GetOtlpDefaultLogsRetryBackoffMultiplier())
-{
+{}
+
+OtlpHttpLogRecordExporterOptions::OtlpHttpLogRecordExporterOptions(void *)
+    : url(),
+      content_type(exporter::otlp::HttpRequestContentType::kBinary),
+      json_bytes_mapping(JsonBytesMappingKind::kHexId),
+      use_json_name(false),
+      console_debug(false),
 #ifdef ENABLE_ASYNC_EXPORT
-  max_concurrent_requests     = 64;
-  max_requests_per_connection = 8;
+      max_concurrent_requests{64},
+      max_requests_per_connection{8},
 #endif
-}
+      ssl_insecure_skip_verify(false)
+{}
 
 OtlpHttpLogRecordExporterOptions::~OtlpHttpLogRecordExporterOptions() {}
 
