@@ -3,7 +3,6 @@
 
 #include <gtest/gtest.h>
 #include <stddef.h>
-#include <algorithm>
 #include <chrono>
 #include <string>
 #include <utility>
@@ -11,10 +10,11 @@
 
 #include "opentelemetry/common/timestamp.h"
 #include "opentelemetry/exporters/otlp/otlp_metric_utils.h"
+#include "opentelemetry/nostd/string_view.h"
 #include "opentelemetry/nostd/unique_ptr.h"
-#include "opentelemetry/nostd/variant.h"
 #include "opentelemetry/sdk/common/attribute_utils.h"
 #include "opentelemetry/sdk/instrumentationscope/instrumentation_scope.h"
+#include "opentelemetry/sdk/metrics/data/circular_buffer.h"
 #include "opentelemetry/sdk/metrics/data/metric_data.h"
 #include "opentelemetry/sdk/metrics/data/point_data.h"
 #include "opentelemetry/sdk/metrics/export/metric_producer.h"
@@ -127,6 +127,60 @@ static metrics_sdk::MetricData CreateHistogramAggregationData()
   return data;
 }
 
+static metrics_sdk::MetricData CreateExponentialHistogramAggregationData(
+    const std::chrono::system_clock::time_point &now_time)
+{
+  metrics_sdk::MetricData data;
+  data.start_ts                               = opentelemetry::common::SystemTimestamp(now_time);
+  metrics_sdk::InstrumentDescriptor inst_desc = {"Histogram", "desc", "unit",
+                                                 metrics_sdk::InstrumentType::kHistogram,
+                                                 metrics_sdk::InstrumentValueType::kDouble};
+  metrics_sdk::Base2ExponentialHistogramPointData s_data_1, s_data_2;
+  s_data_1.count_          = 3;
+  s_data_1.sum_            = 6.5;
+  s_data_1.min_            = 0.0;
+  s_data_1.max_            = 3.5;
+  s_data_1.scale_          = 3;
+  s_data_1.record_min_max_ = true;
+  s_data_1.zero_count_     = 1;
+  s_data_1.positive_buckets_ =
+      std::make_unique<opentelemetry::sdk::metrics::AdaptingCircularBufferCounter>(10);
+  s_data_1.negative_buckets_ =
+      std::make_unique<opentelemetry::sdk::metrics::AdaptingCircularBufferCounter>(10);
+  s_data_1.positive_buckets_->Increment(1, 1);
+  s_data_1.negative_buckets_->Increment(-2, 1);
+
+  s_data_2.count_          = 4;
+  s_data_2.sum_            = 6.2;
+  s_data_2.min_            = -0.03;
+  s_data_2.max_            = 3.5;
+  s_data_2.scale_          = 3;
+  s_data_2.record_min_max_ = false;
+  s_data_2.zero_count_     = 2;
+  s_data_2.positive_buckets_ =
+      std::make_unique<opentelemetry::sdk::metrics::AdaptingCircularBufferCounter>(10);
+  s_data_2.negative_buckets_ =
+      std::make_unique<opentelemetry::sdk::metrics::AdaptingCircularBufferCounter>(10);
+  s_data_2.positive_buckets_->Increment(3, 1);
+  s_data_2.negative_buckets_->Increment(-2, 1);
+  s_data_2.negative_buckets_->Increment(-4, 2);
+
+  data.aggregation_temporality = metrics_sdk::AggregationTemporality::kCumulative;
+  data.end_ts                  = opentelemetry::common::SystemTimestamp(now_time);
+  data.instrument_descriptor   = inst_desc;
+  metrics_sdk::PointDataAttributes point_data_attr_1, point_data_attr_2;
+  point_data_attr_1.attributes = {{"k1", "v1"}};
+  point_data_attr_1.point_data = s_data_1;
+
+  point_data_attr_2.attributes = {{"k2", "v2"}};
+  point_data_attr_2.point_data = s_data_2;
+  std::vector<metrics_sdk::PointDataAttributes> point_data_attr;
+  point_data_attr.push_back(point_data_attr_1);
+  point_data_attr.push_back(point_data_attr_2);
+  data.point_data_attr_ = std::move(point_data_attr);
+  return data;
+}
+
 static metrics_sdk::MetricData CreateObservableGaugeAggregationData()
 {
   metrics_sdk::MetricData data;
@@ -261,6 +315,65 @@ TEST(OtlpMetricSerializationTest, Histogram)
   EXPECT_EQ(1, 1);
 }
 
+TEST(OtlpMetricSerializationTest, ExponentialHistogramAggregationData)
+{
+  const auto start_test_time = std::chrono::system_clock::now();
+  const auto data            = CreateExponentialHistogramAggregationData(start_test_time);
+  opentelemetry::proto::metrics::v1::ExponentialHistogram exponentialHistogram;
+  otlp_exporter::OtlpMetricUtils::ConvertExponentialHistogramMetric(data, &exponentialHistogram);
+  EXPECT_EQ(exponentialHistogram.aggregation_temporality(),
+            proto::metrics::v1::AggregationTemporality::AGGREGATION_TEMPORALITY_CUMULATIVE);
+
+  EXPECT_EQ(exponentialHistogram.data_points_size(), 2);
+  // Point 1
+  {
+    const auto &data_point1 = exponentialHistogram.data_points(0);
+    EXPECT_EQ(data_point1.count(), 3);
+    EXPECT_EQ(data_point1.sum(), 6.5);
+    EXPECT_EQ(data_point1.min(), 0.0);
+    EXPECT_EQ(data_point1.max(), 3.5);
+    EXPECT_EQ(data_point1.zero_count(), 1);
+    EXPECT_EQ(data_point1.scale(), 3);
+    EXPECT_EQ(data_point1.positive().offset(), 1);
+    EXPECT_EQ(data_point1.positive().bucket_counts_size(), 1);
+    EXPECT_EQ(data_point1.positive().bucket_counts(0), 1);
+    EXPECT_EQ(data_point1.negative().offset(), -2);
+    EXPECT_EQ(data_point1.negative().bucket_counts_size(), 1);
+    EXPECT_EQ(data_point1.negative().bucket_counts(0), 1);
+
+    EXPECT_EQ(data_point1.attributes_size(), 1);
+    EXPECT_EQ(data_point1.attributes(0).key(), "k1");
+    EXPECT_EQ(data_point1.attributes(0).value().string_value(), "v1");
+    EXPECT_EQ(data_point1.start_time_unix_nano(), data.start_ts.time_since_epoch().count());
+    EXPECT_EQ(data_point1.time_unix_nano(), data.end_ts.time_since_epoch().count());
+  }
+
+  // Point 2
+  {
+    const auto &data_point2 = exponentialHistogram.data_points(1);
+    EXPECT_EQ(data_point2.count(), 4);
+    EXPECT_EQ(data_point2.sum(), 6.2);
+    EXPECT_EQ(data_point2.min(), 0.0);
+    EXPECT_EQ(data_point2.max(), 0.0);
+    EXPECT_EQ(data_point2.zero_count(), 2);
+    EXPECT_EQ(data_point2.scale(), 3);
+    EXPECT_EQ(data_point2.positive().offset(), 3);
+    EXPECT_EQ(data_point2.positive().bucket_counts_size(), 1);
+    EXPECT_EQ(data_point2.positive().bucket_counts(0), 1);
+    EXPECT_EQ(data_point2.negative().offset(), -4);
+    EXPECT_EQ(data_point2.negative().bucket_counts_size(), 3);
+    EXPECT_EQ(data_point2.negative().bucket_counts(0), 2);
+    EXPECT_EQ(data_point2.negative().bucket_counts(1), 0);
+    EXPECT_EQ(data_point2.negative().bucket_counts(2), 1);
+    EXPECT_EQ(data_point2.attributes(0).key(), "k2");
+    EXPECT_EQ(data_point2.attributes(0).value().string_value(), "v2");
+    EXPECT_EQ(data_point2.start_time_unix_nano(), data.start_ts.time_since_epoch().count());
+    EXPECT_EQ(data_point2.time_unix_nano(), data.end_ts.time_since_epoch().count());
+  }
+
+  EXPECT_EQ(1, 1);
+}
+
 TEST(OtlpMetricSerializationTest, ObservableGauge)
 {
   metrics_sdk::MetricData data = CreateObservableGaugeAggregationData();
