@@ -47,6 +47,28 @@ namespace client
 namespace curl
 {
 
+class HttpOperationAccessor
+{
+public:
+  OPENTELEMETRY_SANITIZER_NO_THREAD static std::thread::id GetThreadId(
+      const HttpOperation::AsyncData &async_data)
+  {
+#if !(defined(OPENTELEMETRY_HAVE_THREAD_SANITIZER) && OPENTELEMETRY_HAVE_THREAD_SANITIZER)
+    std::atomic_thread_fence(std::memory_order_acquire);
+#endif
+    return async_data.callback_thread;
+  }
+
+  OPENTELEMETRY_SANITIZER_NO_THREAD static void SetThreadId(HttpOperation::AsyncData &async_data,
+                                                            std::thread::id thread_id)
+  {
+    async_data.callback_thread = thread_id;
+#if !(defined(OPENTELEMETRY_HAVE_THREAD_SANITIZER) && OPENTELEMETRY_HAVE_THREAD_SANITIZER)
+    std::atomic_thread_fence(std::memory_order_release);
+#endif
+  }
+};
+
 size_t HttpOperation::WriteMemoryCallback(void *contents, size_t size, size_t nmemb, void *userp)
 {
   HttpOperation *self = reinterpret_cast<HttpOperation *>(userp);
@@ -335,7 +357,7 @@ HttpOperation::~HttpOperation()
     case opentelemetry::ext::http::client::SessionState::Sending: {
       if (async_data_ && async_data_->result_future.valid())
       {
-        if (async_data_->callback_thread != std::this_thread::get_id())
+        if (HttpOperationAccessor::GetThreadId(*async_data_) != std::this_thread::get_id())
         {
           async_data_->result_future.wait();
           last_curl_result_ = async_data_->result_future.get();
@@ -360,7 +382,7 @@ void HttpOperation::Finish()
   if (async_data_ && async_data_->result_future.valid())
   {
     // We should not wait in callback from Cleanup()
-    if (async_data_->callback_thread != std::this_thread::get_id())
+    if (HttpOperationAccessor::GetThreadId(*async_data_) != std::this_thread::get_id())
     {
       async_data_->result_future.wait();
       last_curl_result_ = async_data_->result_future.get();
@@ -412,9 +434,9 @@ void HttpOperation::Cleanup()
     callback.swap(async_data_->callback);
     if (callback)
     {
-      async_data_->callback_thread = std::this_thread::get_id();
+      HttpOperationAccessor::SetThreadId(*async_data_, std::this_thread::get_id());
       callback(*this);
-      async_data_->callback_thread = std::thread::id();
+      HttpOperationAccessor::SetThreadId(*async_data_, std::thread::id());
     }
 
     // Set value to promise to continue Finish()
@@ -515,6 +537,7 @@ std::chrono::system_clock::time_point HttpOperation::NextRetryTime()
 #  define HAVE_TLS_VERSION
 #endif
 
+// NOLINTNEXTLINE(google-runtime-int)
 static long parse_min_ssl_version(const std::string &version)
 {
 #ifdef HAVE_TLS_VERSION
@@ -532,6 +555,7 @@ static long parse_min_ssl_version(const std::string &version)
   return 0;
 }
 
+// NOLINTNEXTLINE(google-runtime-int)
 static long parse_max_ssl_version(const std::string &version)
 {
 #ifdef HAVE_TLS_VERSION
@@ -591,6 +615,7 @@ CURLcode HttpOperation::SetCurlPtrOption(CURLoption option, void *value)
   return rc;
 }
 
+// NOLINTNEXTLINE(google-runtime-int)
 CURLcode HttpOperation::SetCurlLongOption(CURLoption option, long value)
 {
   CURLcode rc;
@@ -877,8 +902,10 @@ CURLcode HttpOperation::Setup()
 
 #ifdef HAVE_TLS_VERSION
     /* By default, TLSv1.2 or better is required (if we have TLS). */
+    // NOLINTNEXTLINE(google-runtime-int)
     long min_ssl_version = CURL_SSLVERSION_TLSv1_2;
 #else
+    // NOLINTNEXTLINE(google-runtime-int)
     long min_ssl_version = 0;
 #endif
 
@@ -903,6 +930,7 @@ CURLcode HttpOperation::Setup()
      * The CURL + openssl library may be more recent than this code,
      * and support a version we do not know about.
      */
+    // NOLINTNEXTLINE(google-runtime-int)
     long max_ssl_version = 0;
 
     if (!ssl_options_.ssl_max_tls.empty())
@@ -921,6 +949,7 @@ CURLcode HttpOperation::Setup()
 #endif
     }
 
+    // NOLINTNEXTLINE(google-runtime-int)
     long version_range = min_ssl_version | max_ssl_version;
     if (version_range != 0)
     {
@@ -967,6 +996,7 @@ CURLcode HttpOperation::Setup()
     if (ssl_options_.ssl_insecure_skip_verify)
     {
       /* 6 - DO NOT ENFORCE VERIFICATION, This is not secure. */
+      // NOLINTNEXTLINE(google-runtime-int)
       rc = SetCurlLongOption(CURLOPT_USE_SSL, static_cast<long>(CURLUSESSL_NONE));
       if (rc != CURLE_OK)
       {
@@ -988,6 +1018,7 @@ CURLcode HttpOperation::Setup()
     else
     {
       /* 6 - ENFORCE VERIFICATION */
+      // NOLINTNEXTLINE(google-runtime-int)
       rc = SetCurlLongOption(CURLOPT_USE_SSL, static_cast<long>(CURLUSESSL_ALL));
       if (rc != CURLE_OK)
       {
@@ -1042,7 +1073,7 @@ CURLcode HttpOperation::Setup()
 
   // TODO: control local port to use
   // curl_easy_setopt(curl, CURLOPT_LOCALPORT, dcf_port);
-
+  // NOLINTNEXTLINE(google-runtime-int)
   rc = SetCurlLongOption(CURLOPT_TIMEOUT_MS, static_cast<long>(http_conn_timeout_.count()));
   if (rc != CURLE_OK)
   {
