@@ -6,6 +6,7 @@
 #include <memory>
 
 #include "opentelemetry/sdk/logs/batch_log_record_processor_options.h"
+#include "opentelemetry/sdk/logs/batch_log_record_processor_runtime_options.h"
 #include "opentelemetry/sdk/logs/exporter.h"
 #include "opentelemetry/sdk/logs/processor.h"
 #include "opentelemetry/version.h"
@@ -28,6 +29,14 @@ public:
    */
   static std::unique_ptr<LogRecordProcessor> Create(std::unique_ptr<LogRecordExporter> &&exporter,
                                                     const BatchLogRecordProcessorOptions &options);
+
+  /**
+   * Create a BatchLogRecordProcessor.
+   */
+  static std::unique_ptr<LogRecordProcessor> Create(
+      std::unique_ptr<LogRecordExporter> &&exporter,
+      const BatchLogRecordProcessorOptions &options,
+      const BatchLogRecordProcessorRuntimeOptions &runtime_options);
 };
 
 }  // namespace logs
