@@ -18,8 +18,11 @@ namespace metrics
 {
 
 using PointAttributes = opentelemetry::sdk::common::OrderedAttributeMap;
-using PointType       = opentelemetry::nostd::
-    variant<SumPointData, HistogramPointData, LastValuePointData, DropPointData>;
+using PointType       = opentelemetry::nostd::variant<SumPointData,
+                                                      HistogramPointData,
+                                                      Base2ExponentialHistogramPointData,
+                                                      LastValuePointData,
+                                                      DropPointData>;
 
 struct PointDataAttributes
 {
