@@ -5,27 +5,13 @@
 
 #ifdef ENABLE_METRICS_EXEMPLAR_PREVIEW
 
-#  include <memory>
-
-#  include "opentelemetry/sdk/metrics/state/filtered_ordered_attribute_map.h"
 #  include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
-namespace context
-{
-class Context;
-}  // namespace context
-
 namespace sdk
 {
-namespace common
-{
-class OrderedAttributeMap;
-}  // namespace common
-
 namespace metrics
 {
-using MetricAttributes = opentelemetry::sdk::metrics::FilteredOrderedAttributeMap;
 
 /**
  * Exemplar filter type is used to pre-filter measurements before attempting to store them in a
