@@ -6,6 +6,7 @@
 #include <memory>
 
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_options.h"
+#include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_runtime_options.h"
 #include "opentelemetry/sdk/metrics/metric_reader.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
 #include "opentelemetry/version.h"
@@ -20,7 +21,12 @@ class OPENTELEMETRY_EXPORT PeriodicExportingMetricReaderFactory
 {
 public:
   static std::unique_ptr<MetricReader> Create(std::unique_ptr<PushMetricExporter> exporter,
-                                              const PeriodicExportingMetricReaderOptions &option);
+                                              const PeriodicExportingMetricReaderOptions &options);
+
+  static std::unique_ptr<MetricReader> Create(
+      std::unique_ptr<PushMetricExporter> exporter,
+      const PeriodicExportingMetricReaderOptions &options,
+      const PeriodicExportingMetricReaderRuntimeOptions &runtime_options);
 };
 
 }  // namespace metrics
