@@ -19,7 +19,14 @@ using ResourceAttributes = opentelemetry::sdk::common::AttributeMap;
 class Resource
 {
 public:
-  Resource(const Resource &) = default;
+  Resource() noexcept;
+
+  Resource(const ResourceAttributes &attributes) noexcept;
+
+  Resource(const ResourceAttributes &attributes, const std::string &schema_url) noexcept;
+
+  Resource(const Resource &)            = default;
+  Resource &operator=(const Resource &) = default;
 
   const ResourceAttributes &GetAttributes() const noexcept;
   const std::string &GetSchemaURL() const noexcept;
@@ -61,21 +68,9 @@ public:
 
   static Resource &GetDefault();
 
-protected:
-  /**
-   * The constructor is protected and only for use internally by the class and
-   * inside ResourceDetector class.
-   * Users should use the Create factory method to obtain a Resource
-   * instance.
-   */
-  Resource(const ResourceAttributes &attributes = ResourceAttributes(),
-           const std::string &schema_url        = std::string{}) noexcept;
-
 private:
   ResourceAttributes attributes_;
   std::string schema_url_;
-
-  friend class ResourceDetector;
 };
 
 }  // namespace resource
