@@ -6,6 +6,7 @@
 #include <memory>
 
 #include "opentelemetry/sdk/trace/batch_span_processor_options.h"
+#include "opentelemetry/sdk/trace/batch_span_processor_runtime_options.h"
 #include "opentelemetry/sdk/trace/exporter.h"
 #include "opentelemetry/sdk/trace/processor.h"
 #include "opentelemetry/version.h"
@@ -27,6 +28,14 @@ public:
    */
   static std::unique_ptr<SpanProcessor> Create(std::unique_ptr<SpanExporter> &&exporter,
                                                const BatchSpanProcessorOptions &options);
+
+  /**
+   * Create a BatchSpanProcessor.
+   */
+  static std::unique_ptr<SpanProcessor> Create(
+      std::unique_ptr<SpanExporter> &&exporter,
+      const BatchSpanProcessorOptions &options,
+      const BatchSpanProcessorRuntimeOptions &runtime_options);
 };
 
 }  // namespace trace
