@@ -1,7 +1,6 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
-#include <algorithm>
 #include <chrono>
 #include <memory>
 #include <utility>
@@ -22,15 +21,17 @@ namespace logs
 MultiLogRecordProcessor::MultiLogRecordProcessor(
     std::vector<std::unique_ptr<LogRecordProcessor>> &&processors)
 {
-  for (auto &processor : processors)
+  auto log_record_processors = std::move(processors);
+  for (auto &processor : log_record_processors)
   {
     AddProcessor(std::move(processor));
   }
 }
+
 MultiLogRecordProcessor::~MultiLogRecordProcessor()
 {
-  ForceFlush();
-  Shutdown();
+  InternalForceFlush();
+  InternalShutdown();
 }
 
 void MultiLogRecordProcessor::AddProcessor(std::unique_ptr<LogRecordProcessor> &&processor)
@@ -55,11 +56,12 @@ std::unique_ptr<Recordable> MultiLogRecordProcessor::MakeRecordable() noexcept
 
 void MultiLogRecordProcessor::OnEmit(std::unique_ptr<Recordable> &&record) noexcept
 {
-  if (!record)
+  auto log_record = std::move(record);
+  if (!log_record)
   {
     return;
   }
-  auto multi_recordable = static_cast<MultiRecordable *>(record.get());
+  auto multi_recordable = static_cast<MultiRecordable *>(log_record.get());
 
   for (auto &processor : processors_)
   {
@@ -73,77 +75,76 @@ void MultiLogRecordProcessor::OnEmit(std::unique_ptr<Recordable> &&record) noexc
 
 bool MultiLogRecordProcessor::ForceFlush(std::chrono::microseconds timeout) noexcept
 {
-  // Convert to nanos to prevent overflow
-  std::chrono::nanoseconds timeout_ns = std::chrono::nanoseconds::max();
-  if (std::chrono::duration_cast<std::chrono::microseconds>(timeout_ns) > timeout)
-  {
-    timeout_ns = std::chrono::duration_cast<std::chrono::nanoseconds>(timeout);
-  }
+  return InternalForceFlush(timeout);
+}
+
+bool MultiLogRecordProcessor::Shutdown(std::chrono::microseconds timeout) noexcept
+{
+  return InternalShutdown(timeout);
+}
+
+bool MultiLogRecordProcessor::InternalForceFlush(std::chrono::microseconds timeout) noexcept
+{
   bool result           = true;
   auto start_time       = std::chrono::system_clock::now();
   auto overflow_checker = std::chrono::system_clock::time_point::max();
   std::chrono::system_clock::time_point expire_time;
-  if (overflow_checker - start_time <= timeout_ns)
+  if (std::chrono::duration_cast<std::chrono::microseconds>(overflow_checker - start_time) <=
+      timeout)
   {
     expire_time = overflow_checker;
   }
   else
   {
     expire_time =
-        start_time + std::chrono::duration_cast<std::chrono::system_clock::duration>(timeout_ns);
+        start_time + std::chrono::duration_cast<std::chrono::system_clock::duration>(timeout);
   }
   for (auto &processor : processors_)
   {
-    if (!processor->ForceFlush(std::chrono::duration_cast<std::chrono::microseconds>(timeout_ns)))
+    if (!processor->ForceFlush(timeout))
     {
       result = false;
     }
     start_time = std::chrono::system_clock::now();
     if (expire_time > start_time)
     {
-      timeout_ns = std::chrono::duration_cast<std::chrono::nanoseconds>(expire_time - start_time);
+      timeout = std::chrono::duration_cast<std::chrono::microseconds>(expire_time - start_time);
     }
     else
     {
-      timeout_ns = std::chrono::nanoseconds::zero();
+      timeout = std::chrono::microseconds::zero();
     }
   }
   return result;
 }
 
-bool MultiLogRecordProcessor::Shutdown(std::chrono::microseconds timeout) noexcept
+bool MultiLogRecordProcessor::InternalShutdown(std::chrono::microseconds timeout) noexcept
 {
-  // Converto nanos to prevent overflow
-  std::chrono::nanoseconds timeout_ns = std::chrono::nanoseconds::max();
-  if (std::chrono::duration_cast<std::chrono::microseconds>(timeout_ns) > timeout)
-  {
-    timeout_ns = std::chrono::duration_cast<std::chrono::nanoseconds>(timeout);
-  }
   bool result           = true;
   auto start_time       = std::chrono::system_clock::now();
   auto overflow_checker = std::chrono::system_clock::time_point::max();
   std::chrono::system_clock::time_point expire_time;
-  if (overflow_checker - start_time <= timeout_ns)
+  if (std::chrono::duration_cast<std::chrono::microseconds>(overflow_checker - start_time) <=
+      timeout)
   {
     expire_time = overflow_checker;
   }
   else
   {
     expire_time =
-        start_time + std::chrono::duration_cast<std::chrono::system_clock::duration>(timeout_ns);
+        start_time + std::chrono::duration_cast<std::chrono::system_clock::duration>(timeout);
   }
   for (auto &processor : processors_)
   {
-    result |=
-        processor->Shutdown(std::chrono::duration_cast<std::chrono::microseconds>(timeout_ns));
+    result |= processor->Shutdown(timeout);
     start_time = std::chrono::system_clock::now();
     if (expire_time > start_time)
     {
-      timeout_ns = std::chrono::duration_cast<std::chrono::nanoseconds>(expire_time - start_time);
+      timeout = std::chrono::duration_cast<std::chrono::microseconds>(expire_time - start_time);
     }
     else
     {
-      timeout_ns = std::chrono::nanoseconds::zero();
+      timeout = std::chrono::microseconds::zero();
     }
   }
   return result;
