@@ -1,7 +1,6 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
-#include <algorithm>
 #include <atomic>
 #include <chrono>
 #include <memory>
@@ -31,6 +30,10 @@
 #include "opentelemetry/sdk/resource/resource.h"
 #include "opentelemetry/version.h"
 
+#ifdef ENABLE_METRICS_EXEMPLAR_PREVIEW
+#  include "opentelemetry/sdk/metrics/exemplar/filter_type.h"
+#endif  // ENABLE_METRICS_EXEMPLAR_PREVIEW
+
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace sdk
 {
