@@ -5,12 +5,14 @@
 #include <utility>
 #include <vector>
 
+#include "opentelemetry/sdk/instrumentationscope/scope_configurator.h"
 #include "opentelemetry/sdk/resource/resource.h"
 #include "opentelemetry/sdk/trace/id_generator.h"
 #include "opentelemetry/sdk/trace/processor.h"
 #include "opentelemetry/sdk/trace/random_id_generator_factory.h"
 #include "opentelemetry/sdk/trace/sampler.h"
 #include "opentelemetry/sdk/trace/samplers/always_on_factory.h"
+#include "opentelemetry/sdk/trace/tracer_config.h"
 #include "opentelemetry/sdk/trace/tracer_context.h"
 #include "opentelemetry/sdk/trace/tracer_provider.h"
 #include "opentelemetry/sdk/trace/tracer_provider_factory.h"
@@ -51,10 +53,26 @@ std::unique_ptr<opentelemetry::sdk::trace::TracerProvider> TracerProviderFactory
     const opentelemetry::sdk::resource::Resource &resource,
     std::unique_ptr<Sampler> sampler,
     std::unique_ptr<IdGenerator> id_generator)
+{
+  auto tracer_configurator =
+      std::make_unique<instrumentationscope::ScopeConfigurator<TracerConfig>>(
+          instrumentationscope::ScopeConfigurator<TracerConfig>::Builder(TracerConfig::Default())
+              .Build());
+  return Create(std::move(processor), resource, std::move(sampler), std::move(id_generator),
+                std::move(tracer_configurator));
+}
+
+std::unique_ptr<opentelemetry::sdk::trace::TracerProvider> TracerProviderFactory::Create(
+    std::unique_ptr<SpanProcessor> processor,
+    const opentelemetry::sdk::resource::Resource &resource,
+    std::unique_ptr<Sampler> sampler,
+    std::unique_ptr<IdGenerator> id_generator,
+    std::unique_ptr<instrumentationscope::ScopeConfigurator<TracerConfig>> tracer_configurator)
 {
   std::unique_ptr<opentelemetry::sdk::trace::TracerProvider> provider(
       new opentelemetry::sdk::trace::TracerProvider(std::move(processor), resource,
-                                                    std::move(sampler), std::move(id_generator)));
+                                                    std::move(sampler), std::move(id_generator),
+                                                    std::move(tracer_configurator)));
   return provider;
 }
 
@@ -87,10 +105,26 @@ std::unique_ptr<opentelemetry::sdk::trace::TracerProvider> TracerProviderFactory
     const opentelemetry::sdk::resource::Resource &resource,
     std::unique_ptr<Sampler> sampler,
     std::unique_ptr<IdGenerator> id_generator)
+{
+  auto tracer_configurator =
+      std::make_unique<instrumentationscope::ScopeConfigurator<TracerConfig>>(
+          instrumentationscope::ScopeConfigurator<TracerConfig>::Builder(TracerConfig::Default())
+              .Build());
+  return Create(std::move(processors), resource, std::move(sampler), std::move(id_generator),
+                std::move(tracer_configurator));
+}
+
+std::unique_ptr<opentelemetry::sdk::trace::TracerProvider> TracerProviderFactory::Create(
+    std::vector<std::unique_ptr<SpanProcessor>> &&processors,
+    const opentelemetry::sdk::resource::Resource &resource,
+    std::unique_ptr<Sampler> sampler,
+    std::unique_ptr<IdGenerator> id_generator,
+    std::unique_ptr<instrumentationscope::ScopeConfigurator<TracerConfig>> tracer_configurator)
 {
   std::unique_ptr<opentelemetry::sdk::trace::TracerProvider> provider(
       new opentelemetry::sdk::trace::TracerProvider(std::move(processors), resource,
-                                                    std::move(sampler), std::move(id_generator)));
+                                                    std::move(sampler), std::move(id_generator),
+                                                    std::move(tracer_configurator)));
   return provider;
 }
 
