@@ -144,7 +144,7 @@ meter_provider:
   readers:
     - pull:
         exporter:
-          prometheus:
+          prometheus/development:
 )";
 
   auto config = DoParse(yaml);
@@ -519,7 +519,7 @@ meter_provider:
   readers:
     - pull:
         exporter:
-          prometheus:
+          prometheus/development:
 )";
 
   auto config = DoParse(yaml);
@@ -550,7 +550,7 @@ meter_provider:
   readers:
     - pull:
         exporter:
-          prometheus:
+          prometheus/development:
             host: "prometheus"
             port: 1234
             without_units: true
