@@ -4,6 +4,7 @@
 #include <gtest/gtest.h>
 #include <stddef.h>
 #include <chrono>
+#include <cstdlib>
 #include <memory>
 #include <ratio>
 #include <thread>
@@ -18,6 +19,12 @@
 #include "opentelemetry/sdk/metrics/instruments.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
 
+#if defined(_MSC_VER)
+#  include "opentelemetry/sdk/common/env_variables.h"
+using opentelemetry::sdk::common::setenv;
+using opentelemetry::sdk::common::unsetenv;
+#endif
+
 using namespace opentelemetry;
 using namespace opentelemetry::sdk::instrumentationscope;
 using namespace opentelemetry::sdk::metrics;
@@ -76,7 +83,7 @@ private:
   size_t data_sent_size_{0};
 };
 
-TEST(PeriodicExporingMetricReader, BasicTests)
+TEST(PeriodicExportingMetricReader, BasicTests)
 {
   std::unique_ptr<PushMetricExporter> exporter(
       new MockPushMetricExporter(std::chrono::milliseconds{0}));
@@ -95,7 +102,7 @@ TEST(PeriodicExporingMetricReader, BasicTests)
             static_cast<MockMetricProducer *>(&producer)->GetDataCount());
 }
 
-TEST(PeriodicExporingMetricReader, Timeout)
+TEST(PeriodicExportingMetricReader, Timeout)
 {
   std::unique_ptr<PushMetricExporter> exporter(
       new MockPushMetricExporter(std::chrono::milliseconds{2000}));
@@ -109,3 +116,32 @@ TEST(PeriodicExporingMetricReader, Timeout)
   std::this_thread::sleep_for(std::chrono::milliseconds(1000));
   reader->Shutdown();
 }
+
+TEST(PeriodicExportingMetricReaderOptions, UsesEnvVars)
+{
+  const char *env_interval = "OTEL_METRIC_EXPORT_INTERVAL";
+  const char *env_timeout  = "OTEL_METRIC_EXPORT_TIMEOUT";
+
+  setenv(env_interval, "1500ms", 1);
+  setenv(env_timeout, "1000ms", 1);
+
+  PeriodicExportingMetricReaderOptions options;
+  EXPECT_EQ(options.export_interval_millis, std::chrono::milliseconds(1500));
+  EXPECT_EQ(options.export_timeout_millis, std::chrono::milliseconds(1000));
+
+  unsetenv(env_interval);
+  unsetenv(env_timeout);
+}
+
+TEST(PeriodicExportingMetricReaderOptions, UsesDefault)
+{
+  const char *env_interval = "OTEL_METRIC_EXPORT_INTERVAL";
+  const char *env_timeout  = "OTEL_METRIC_EXPORT_TIMEOUT";
+
+  unsetenv(env_interval);
+  unsetenv(env_timeout);
+
+  PeriodicExportingMetricReaderOptions options;
+  EXPECT_EQ(options.export_interval_millis, std::chrono::milliseconds(60000));
+  EXPECT_EQ(options.export_timeout_millis, std::chrono::milliseconds(30000));
+}
