@@ -10,10 +10,9 @@
 
 #include "opentelemetry/common/key_value_iterable_view.h"
 #include "opentelemetry/context/context.h"
-#include "opentelemetry/nostd/utility.h"
+#include "opentelemetry/nostd/string_view.h"
 #include "opentelemetry/sdk/instrumentationscope/instrumentation_scope.h"
 #include "opentelemetry/sdk/metrics/instruments.h"
-#include "opentelemetry/sdk/metrics/state/filtered_ordered_attribute_map.h"
 #include "opentelemetry/sdk/metrics/state/metric_storage.h"
 #include "opentelemetry/sdk/metrics/state/multi_metric_storage.h"
 #include "opentelemetry/sdk/metrics/sync_instruments.h"
@@ -112,6 +111,45 @@ TEST(SyncInstruments, DoubleUpDownCounter)
   counter.Add(10.10, opentelemetry::common::KeyValueIterableView<M>({}));
 }
 
+#if OPENTELEMETRY_ABI_VERSION_NO >= 2
+TEST(SyncInstruments, LongGauge)
+{
+  InstrumentDescriptor instrument_descriptor = {"long_gauge", "description", "1",
+                                                InstrumentType::kGauge, InstrumentValueType::kLong};
+  std::unique_ptr<SyncWritableMetricStorage> metric_storage(new SyncMultiMetricStorage());
+  LongGauge gauge(instrument_descriptor, std::move(metric_storage));
+  gauge.Record(10);
+  gauge.Record(10, opentelemetry::context::Context{});
+
+  gauge.Record(10, opentelemetry::common::KeyValueIterableView<M>({{"abc", "123"}, {"xyz", "456"}}),
+               opentelemetry::context::Context{});
+  gauge.Record(10,
+               opentelemetry::common::KeyValueIterableView<M>({{"abc", "123"}, {"xyz", "456"}}));
+  gauge.Record(10, opentelemetry::common::KeyValueIterableView<M>({}),
+               opentelemetry::context::Context{});
+  gauge.Record(10, opentelemetry::common::KeyValueIterableView<M>({}));
+}
+
+TEST(SyncInstruments, DoubleGauge)
+{
+  InstrumentDescriptor instrument_descriptor = {
+      "double_gauge", "description", "1", InstrumentType::kGauge, InstrumentValueType::kDouble};
+  std::unique_ptr<SyncWritableMetricStorage> metric_storage(new SyncMultiMetricStorage());
+  DoubleGauge gauge(instrument_descriptor, std::move(metric_storage));
+  gauge.Record(10.10);
+  gauge.Record(10.10, opentelemetry::context::Context{});
+
+  gauge.Record(10.10,
+               opentelemetry::common::KeyValueIterableView<M>({{"abc", "123"}, {"xyz", "456"}}),
+               opentelemetry::context::Context{});
+  gauge.Record(10.10,
+               opentelemetry::common::KeyValueIterableView<M>({{"abc", "123"}, {"xyz", "456"}}));
+  gauge.Record(10.10, opentelemetry::common::KeyValueIterableView<M>({}),
+               opentelemetry::context::Context{});
+  gauge.Record(10.10, opentelemetry::common::KeyValueIterableView<M>({}));
+}
+#endif
+
 TEST(SyncInstruments, LongHistogram)
 {
   InstrumentDescriptor instrument_descriptor = {
